summaryrefslogtreecommitdiffstats
path: root/src/libhomescreen.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/libhomescreen.cpp')
-rw-r--r--src/libhomescreen.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/libhomescreen.cpp b/src/libhomescreen.cpp
index c3e76ba..29ba7ef 100644
--- a/src/libhomescreen.cpp
+++ b/src/libhomescreen.cpp
@@ -203,12 +203,12 @@ END:
* When HomeScreen shortcut area is tapped, sending a event
*
* #### Parameters
* - application_name [in] : Tapped application name (label)
*
* #### Return
* - Returns 0 on success or -1 in case of error.
*/
-int LibHomeScreen::tapShortcut(const char* application_name)
+int LibHomeScreen::tapShortcut(const char* application_id)
{
if(!sp_websock)
{
@@ -216,8 +216,8 @@ int LibHomeScreen::tapShortcut(const char* application_name)
}
struct json_object* j_obj = json_object_new_object();
- struct json_object* val = json_object_new_string(application_name);
- json_object_object_add(j_obj, "application_name", val);
+ struct json_object* val = json_object_new_string(application_id);
+ json_object_object_add(j_obj, "application_id", val);
return this->call("tap_shortcut", j_obj);
}
@@ -445,8 +445,8 @@ void LibHomeScreen::on_call(void *closure, const char *api, const char *verb, st
}
/*
-* event is like "homescreen/tap_shortcut"
-* msg is like {"event":"homescreen\/tap_shortcut","data":{"application_name":"hoge"},"jtype":"afb-event"}
+* event is like "homescreen/hvac"
+* msg is like {"event":"homescreen\/hvac","data":{"type":"tap_shortcut"},"jtype":"afb-event"}
* so you can get
event name : struct json_object obj = json_object_object_get(msg,"event")
*/
@@ -203,12 +203,12 @@ END:
*
* #### Parameters
- * - application_name [in] : Tapped application name (label)
+ * - application_id [in] : Tapped application id (label)
*
* #### Return